import { __decorate, __param } from 'tslib';
import { ɵɵdefineInjectable, Injectable, InjectionToken, Inject, ViewChild, Component, NgModule } from '@angular/core';
import { Subject } from 'rxjs';
import { FormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';

let SimpleNgxLoadingBarService = class SimpleNgxLoadingBarService {
    constructor() {
        this.loader = new Subject();
    }
    getLoader() {
        return this.loader;
    }
    show() {
        this.loader.next(true);
    }
    hide() {
        this.loader.next(false);
    }
};
SimpleNgxLoadingBarService.ɵprov = ɵɵdefineInjectable({ factory: function SimpleNgxLoadingBarService_Factory() { return new SimpleNgxLoadingBarService(); }, token: SimpleNgxLoadingBarService, providedIn: "root" });
SimpleNgxLoadingBarService = __decorate([
    Injectable({
        providedIn: 'root'
    })
], SimpleNgxLoadingBarService);

/**
 * This is not a real service, but it looks like it from the outside.
 * It's just an InjectionTToken used to import the config object, provided from the outside
 */
const loadingBarConfigService = new InjectionToken('ConfigSimpleNgxLoadingBarService');

let SimpleNgxLoadingBarComponent = class SimpleNgxLoadingBarComponent {
    constructor(loaderService, config) {
        this.loaderService = loaderService;
        this.config = config;
        this.loadingValue = 0;
        this.isLoading = false;
        this.intervalTime = 500; // ms
    }
    ngOnInit() {
    }
    ngAfterContentInit() {
        this.subscription = this.loaderService.getLoader()
            .subscribe(isLoading => {
            if (isLoading) {
                this.startLoading();
            }
            else {
                this.stopLoading();
            }
        });
    }
    reset() {
        this.loadingValue = 0; // reset
        this.updateElement();
    }
    startLoading() {
        this.loadingValue = 0;
        this.isLoading = true;
        this.intervalId = setInterval(() => {
            this.keepLoading();
        }, this.intervalTime);
    }
    stopLoading() {
        // complete loading line , then clear it
        this.loadingValue = 100;
        this.updateElement();
        setTimeout(() => {
            clearInterval(this.intervalId);
            this.isLoading = false;
        }, this.intervalTime);
    }
    keepLoading() {
        if (this.loadingValue < 95) {
            this.loadingValue += 5;
            this.updateElement();
        }
    }
    updateElement() {
        if (this.loaderEl) {
            this.setupBackgroundColor();
            this.loaderEl.nativeElement.style.width = `${this.loadingValue}%`;
        }
    }
    setupBackgroundColor() {
        const backgroundColor = this.config.color ? this.config.color : '#333';
        if (this.loaderEl) {
            // check is already assigned or not. no need to reassign , only once.
            if (this.loaderEl.nativeElement.style.background != backgroundColor) {
                this.loaderEl.nativeElement.style.background = backgroundColor;
            }
        }
    }
    ngOnDestroy() {
        this.subscription.unsubscribe();
    }
};
SimpleNgxLoadingBarComponent.ctorParameters = () => [
    { type: SimpleNgxLoadingBarService },
    { type: undefined, decorators: [{ type: Inject, args: [loadingBarConfigService,] }] }
];
__decorate([
    ViewChild('loader', { static: false })
], SimpleNgxLoadingBarComponent.prototype, "loaderEl", void 0);
SimpleNgxLoadingBarComponent = __decorate([
    Component({
        selector: 'simple-ngx-loading-bar',
        template: "<ng-container>\n  <div *ngIf=\"isLoading\" #loader class=\"loading-bar-loader\"></div>\n</ng-container>\n",
        styles: [":host{position:absolute;top:0;left:0;width:100%;z-index:999999!important}.loading-bar-loader{height:2px;width:0;transition:width .4s linear}"]
    }),
    __param(1, Inject(loadingBarConfigService))
], SimpleNgxLoadingBarComponent);

var SimpleNgxLoadingBarModule_1;
let SimpleNgxLoadingBarModule = SimpleNgxLoadingBarModule_1 = class SimpleNgxLoadingBarModule {
    static forRoot(config) {
        return {
            ngModule: SimpleNgxLoadingBarModule_1,
            providers: [
                {
                    provide: loadingBarConfigService,
                    useValue: config
                }
            ]
        };
    }
};
SimpleNgxLoadingBarModule = SimpleNgxLoadingBarModule_1 = __decorate([
    NgModule({
        declarations: [SimpleNgxLoadingBarComponent],
        imports: [
            CommonModule,
            FormsModule
        ],
        providers: [
            SimpleNgxLoadingBarService
        ],
        exports: [SimpleNgxLoadingBarComponent]
    })
], SimpleNgxLoadingBarModule);

/*
 * Public API Surface of simple-ngx-loading-bar
 */

/**
 * Generated bundle index. Do not edit.
 */

export { SimpleNgxLoadingBarComponent, SimpleNgxLoadingBarModule, SimpleNgxLoadingBarService, loadingBarConfigService as ɵa };
//# sourceMappingURL=simple-ngx-loading-bar.js.map
