import { __decorate, __param } from 'tslib';
import { ɵɵdefineInjectable, Injectable, InjectionToken, Inject, ViewChild, Component, NgModule } from '@angular/core';
import { Subject } from 'rxjs';
import { FormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';

var SimpleNgxLoadingBarService = /** @class */ (function () {
    function SimpleNgxLoadingBarService() {
        this.loader = new Subject();
    }
    SimpleNgxLoadingBarService.prototype.getLoader = function () {
        return this.loader;
    };
    SimpleNgxLoadingBarService.prototype.show = function () {
        this.loader.next(true);
    };
    SimpleNgxLoadingBarService.prototype.hide = function () {
        this.loader.next(false);
    };
    SimpleNgxLoadingBarService.ɵprov = ɵɵdefineInjectable({ factory: function SimpleNgxLoadingBarService_Factory() { return new SimpleNgxLoadingBarService(); }, token: SimpleNgxLoadingBarService, providedIn: "root" });
    SimpleNgxLoadingBarService = __decorate([
        Injectable({
            providedIn: 'root'
        })
    ], SimpleNgxLoadingBarService);
    return SimpleNgxLoadingBarService;
}());

/**
 * This is not a real service, but it looks like it from the outside.
 * It's just an InjectionTToken used to import the config object, provided from the outside
 */
var loadingBarConfigService = new InjectionToken('ConfigSimpleNgxLoadingBarService');

var SimpleNgxLoadingBarComponent = /** @class */ (function () {
    function SimpleNgxLoadingBarComponent(loaderService, config) {
        this.loaderService = loaderService;
        this.config = config;
        this.loadingValue = 0;
        this.isLoading = false;
        this.intervalTime = 500; // ms
    }
    SimpleNgxLoadingBarComponent.prototype.ngOnInit = function () {
    };
    SimpleNgxLoadingBarComponent.prototype.ngAfterContentInit = function () {
        var _this = this;
        this.subscription = this.loaderService.getLoader()
            .subscribe(function (isLoading) {
            if (isLoading) {
                _this.startLoading();
            }
            else {
                _this.stopLoading();
            }
        });
    };
    SimpleNgxLoadingBarComponent.prototype.reset = function () {
        this.loadingValue = 0; // reset
        this.updateElement();
    };
    SimpleNgxLoadingBarComponent.prototype.startLoading = function () {
        var _this = this;
        this.loadingValue = 0;
        this.isLoading = true;
        this.intervalId = setInterval(function () {
            _this.keepLoading();
        }, this.intervalTime);
    };
    SimpleNgxLoadingBarComponent.prototype.stopLoading = function () {
        var _this = this;
        // complete loading line , then clear it
        this.loadingValue = 100;
        this.updateElement();
        setTimeout(function () {
            clearInterval(_this.intervalId);
            _this.isLoading = false;
        }, this.intervalTime);
    };
    SimpleNgxLoadingBarComponent.prototype.keepLoading = function () {
        if (this.loadingValue < 95) {
            this.loadingValue += 5;
            this.updateElement();
        }
    };
    SimpleNgxLoadingBarComponent.prototype.updateElement = function () {
        if (this.loaderEl) {
            this.setupBackgroundColor();
            this.loaderEl.nativeElement.style.width = this.loadingValue + "%";
        }
    };
    SimpleNgxLoadingBarComponent.prototype.setupBackgroundColor = function () {
        var backgroundColor = this.config.color ? this.config.color : '#333';
        if (this.loaderEl) {
            // check is already assigned or not. no need to reassign , only once.
            if (this.loaderEl.nativeElement.style.background != backgroundColor) {
                this.loaderEl.nativeElement.style.background = backgroundColor;
            }
        }
    };
    SimpleNgxLoadingBarComponent.prototype.ngOnDestroy = function () {
        this.subscription.unsubscribe();
    };
    SimpleNgxLoadingBarComponent.ctorParameters = function () { return [
        { type: SimpleNgxLoadingBarService },
        { type: undefined, decorators: [{ type: Inject, args: [loadingBarConfigService,] }] }
    ]; };
    __decorate([
        ViewChild('loader', { static: false })
    ], SimpleNgxLoadingBarComponent.prototype, "loaderEl", void 0);
    SimpleNgxLoadingBarComponent = __decorate([
        Component({
            selector: 'simple-ngx-loading-bar',
            template: "<ng-container>\n  <div *ngIf=\"isLoading\" #loader class=\"loading-bar-loader\"></div>\n</ng-container>\n",
            styles: [":host{position:absolute;top:0;left:0;width:100%;z-index:999999!important}.loading-bar-loader{height:2px;width:0;transition:width .4s linear}"]
        }),
        __param(1, Inject(loadingBarConfigService))
    ], SimpleNgxLoadingBarComponent);
    return SimpleNgxLoadingBarComponent;
}());

var SimpleNgxLoadingBarModule = /** @class */ (function () {
    function SimpleNgxLoadingBarModule() {
    }
    SimpleNgxLoadingBarModule_1 = SimpleNgxLoadingBarModule;
    SimpleNgxLoadingBarModule.forRoot = function (config) {
        return {
            ngModule: SimpleNgxLoadingBarModule_1,
            providers: [
                {
                    provide: loadingBarConfigService,
                    useValue: config
                }
            ]
        };
    };
    var SimpleNgxLoadingBarModule_1;
    SimpleNgxLoadingBarModule = SimpleNgxLoadingBarModule_1 = __decorate([
        NgModule({
            declarations: [SimpleNgxLoadingBarComponent],
            imports: [
                CommonModule,
                FormsModule
            ],
            providers: [
                SimpleNgxLoadingBarService
            ],
            exports: [SimpleNgxLoadingBarComponent]
        })
    ], SimpleNgxLoadingBarModule);
    return SimpleNgxLoadingBarModule;
}());

/*
 * Public API Surface of simple-ngx-loading-bar
 */

/**
 * Generated bundle index. Do not edit.
 */

export { SimpleNgxLoadingBarComponent, SimpleNgxLoadingBarModule, SimpleNgxLoadingBarService, loadingBarConfigService as ɵa };
//# sourceMappingURL=simple-ngx-loading-bar.js.map
